Raportit | OiRA

Aiheet

# Raportit

Raportin avulla voit

- antaa todisteita valvontaviranomaisille
- välittää tietoja henkilöille, joita asia koskee (työntekijöille, turvallisuusvastaaville, työnantajille, työsuojeluasiantuntijoille jne.)
- seurata ja arvioida, onko tarvittavat toimenpiteet otettu käyttöön
- kirjata kaikki tarkistukset tietoihin, jos olosuhteet muuttuvat (esim. uusien koneiden/työntekijöiden lisääminen tai onnettomuustutkintojen havaintojen perusteella tehdyt muutokset, ym.).

Raportin voi tallentaa tietokoneelle ja tulostaa. Sitä voi myös muuttaa tai siihen voi lisätä tietoja. Huomaathan, että ladattuun raporttiin tekemiäsi muutoksia EI tallenneta OiRA-työkaluun.

## Raporttivalinnat

Eri tarkoituksiin on saatavilla erilaisia raportteja. Tiettyjä työkaluja varten saatavilla olevien raporttien valikoima riippuu kansallisten OiRA-kumppanien / OiRA-työkalun kehittäjien tekemistä valinnoista.

Saatavilla olevat raportit

### Täydellinen raportti

Muoto: Word / Office Open XML (.docx). Tiedostoa voidaan muokata latauksen jälkeen.

Sisältö: kaikki koko riskinarvioinnin aikana antamasi tiedot ja syötteet.

Käyttötarkoitus: todisteiden antaminen suoritetusta riskinarvioinnista valvontaviranomaisille (esim. työsuojelutarkastajalle).

### Toimintasuunnitelma

Muoto: Excel / Office Open XML (.xlsx). Tiedostoa voidaan muokata latauksen jälkeen.

Sisältö: tiedot kaikista toimenpiteistä, jotka olet päättänyt toteuttaa.

Käyttötarkoitus:

- valittujen toimenpiteiden täytäntöönpanon aktiivinen seuranta
- työpaikan ongelmien/riskien hallinta (erityiset tehtävät, asiantuntemus, vastuut, määräajat).

### Yleiskatsaus riskeistä

Muoto: Portable Document Format (.pdf). Tiedostoa ei voi muokata latauksen jälkeen.

Sisältö: yleiskatsaus määritettyihin riskeihin

Käyttötarkoitus:

- nopea katsaus työpaikan riskien tilaan
- tietojen välittäminen tahoille, joita asia koskee
- seuranta siitä, huolehditaanko riskeistä/toimenpiteistä asianmukaisesti.

### Yleiskatsaus toimenpiteistä

Muoto: Portable Document Format (.pdf). Tiedostoa ei voi muokata latauksen jälkeen.

Sisältö: lyhyt yleiskatsaus toteutettaviin toimenpiteisiin.

Käyttötarkoitus:

- nopea yleiskatsaus niiden toimenpiteiden tilaan, jotka olet päättänyt toteuttaa
- tietojen välittäminen tahoille, joita asia koskee
- seuranta siitä, huolehditaanko riskeistä/toimenpiteistä asianmukaisesti.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More